==> oddmuse-1.806.tar.gz: oddmuse-1.806/hebrew-utf8.pl <==
# UTF-8 encoded Hebrew language file for use with Oddmuse
#
# Copyright (c) 2003  Erez Zukerman, IDP, ezuk at idp dot co dot il
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: hebrew-utf8.pl,v 1.10 2007/08/19 11:42:08 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Login

Error

%s calls

Could not create %s
לא ניתן ליצור את %s
Invalid UserName %s: not saved.
שם משתמש שגוי: %s לא נשמר.
UserName must be 50 characters or less: not saved
שם המשתמש חייב להיות באורך 50 תווים או פחות: לא נשמר
This page contains an uploaded file:

Recursive include of %s!

Clear Cache

Main lock obtained.
נעילה ראשית הושגה.
Main lock released.
נעילה ראשית שוחררה.
Journal

More...

Comments on this page
הערות בדף זה
XML::RSS is not available on this system.

diff

history
היסטוריה
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

CGI Internal error: %s

Invalid action parameter %s
פרמטר שגוי לפעולה: %s
Invalid URL.
כתובת שגויה.
Page name is missing

Page name is too long: %s
שם הדף ארוך מדי: %s
Invalid Page %s (must not end with .db)
דף לא חוקי %s (אסור שיסתיים בסיומת .db)
Invalid Page %s (must not end with .lck)
דף לא חוקי %s (אסור שיסתיים בסיומת .lck)
Invalid Page %s
דף לא חוקי %s
Preview:
תצוגה מקדימה:
Preview only, not yet saved
תצוגה מקדימה בלבד, הדף עדיין לא נשמר.
Please go on to %s.
בבקשה המשך ל-%s.
All changes for %s

No updates since %s
אין עדכונים מאז %s
Updates since %s
עדכונים מאז %s
Updates in the last %s days
עדכונים ב%s הימים האחרונים
Updates in the last %s day
עדכונים ביום האחרון
for %s only
עבור %s בלבד
List latest change per page only

List all changes

Skip rollbacks

Include rollbacks

List only major changes

Include minor changes

%s days
%s ימים
List later changes

RSS

RSS with pages

RSS with pages and diff

Filters

Title:

Title and Body:

Username:
שם משתמש:
Host:

Follow up to:

Language:

Go!
חפש!
(minor)
(קטן)
rollback

new

from %s
מ %s
: 

This page is too big to send over RSS.

History of %s
היסטוריה של %s
Compare
השוואה
Deleted

Mark this page for deletion

No other revisions available

current

Revision %s
עדכון %s
Contributors to %s

Missing target for rollback.

Target for rollback is too far back.

A username is required for ordinary users.

Rolling back changes

The two revisions are the same.

Editing not allowed for %s.
לא ניתן לערוך את %s.
Rollback to %s

%s rolled back

to %s

Index of all pages
תוכן כל הדפים:
Wiki Version
מציג את גירסת ה-Wiki.
Unlock Wiki
משחרר נעילה
Password
ססמה
Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[דף בית]
redirected from %s
הוכוון מחדש מ %s
Click to search for references to this page

Cookie: 

Warning
אזהרה
Database is stored in temporary directory %s
מסד הנתונים מאוחסן בספריה זמנית %s
%s seconds
%s שניות
The same page on other sites:

EditNearLinks

Last edited
עריכה אחרונה
Edited
נערך
by %s

(diff)
(הבדלים)
Edit revision %s of this page
ערוך את גירסה %s של דף זה
Edit this page
ערוך את הטקסט של דף זה.
e

This page is read-only
דף זה מיועד לקריאה בלבד
View other revisions
הצג גרסאות אחרות
View current revision
הצג את הגירסה העדכנית
View all changes

View contributors

Homepage URL:

s

Save
שמור
p

Preview
תצוגה מקדימה
Search:
חיפוש:
f

Replace:
החלפה:
Delete

Validate HTML
אמת HTML
Validate CSS
אמת CSS
Last edit

Difference between revision %1 and %2

revision %s
עדכון %s
current revision
גירסה נוכחית
Last major edit (%s)

later minor edits

No diff available.
לא ניתן להשיג הבדלים
Old revision:

Changed:
שונה:
Deleted:

Added:
התווסף:
to
אל
Revision %s not available
גירסה %s אינה זמינה.
showing current revision instead
מציג את הגירסה הנוכחית במקומה.
Showing revision %s
מציג את גירסה %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...
פעולה זו עשויה להימשך מספר שניות...
Forced unlock of %s lock.
שוחררה נעילה של %s.
No unlock required.
אין צורך לשחרר נעילה.
%s hours ago
לפני %s שעות.
1 hour ago
לפני שעה
%s minutes ago
לפני %s דקות
1 minute ago
לפני דקה
%s seconds ago
לפני %s שניות
1 second ago
לפני שניה
just now
ממש עכשיו
Edit Denied

Editing not allowed: user, ip, or network is blocked.
עריכה אסורה: משתמש, כתובת או רשת חסומים
Contact the wiki administrator for more information.
צור קשר עם מנהל המערכת למידע נוסף
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
לא ניתן לערוך: %s מיועד לקריאה בלבד.
Only administrators can upload files.

Editing revision %s of
עורך את גירסה %s של
Editing %s
עורך את %s
Editing old revision %s.
עורך גירסה ישנה %s.
Saving this page will replace the latest revision with this text.
שמירת דף זה תחליף את הגירסה החדשה ביותר בטקסט זה.
Summary:
תקציר:
This change is a minor edit.
השינוי שאני מבצע הוא קטן.
Cancel

Replace this file with text

Replace this text with a file

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
הססמה שלך נשמרת כ-cookie, אם cookies מופעלות. Cookies עלולות ללכת לאיבוד אם תתחבר ממחשב אחר או מתוכנה אחרת.
You are currently an administrator on this site.
אתה כרגע מנהל באתר זה.
You are currently an editor on this site.
אתה כרגע עורך באתר זה.
You are a normal user on this site.
אתה משתמש רגיל באתר זה.
Your password does not match any of the  administrator or editor passwords.
הססמה שלך לא מתאימה ללסמאות של המנהל או העורך.
Password:
ססמה:
This site does not use admin or editor passwords.
אתר זה לא משתמש בססמאות מנהל ועורך.
This operation is restricted to site editors only...
פעולה זו מוגבלת לעורכים בלבד...
This operation is restricted to administrators only...
פעולה זו מוגבלת למנהלים בלבד...
SampleUndefinedPage

Sample_Undefined_Page
דף_לא_מוגדר_לדוגמא
Rule "%1" matched "%2" on this page.

Reason: %s.

Reason unknown.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

Filter:

%s pages found.

Replaced: %s
הוחלף: %s
Search for: %s
חיפוש של: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
עדכון אחרון
by
על-ידי
Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
אנונימי
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
לא ניתן לגרום לנעילה להתמזג!
you

ancestor

other

Run Maintenance

Maintenance not done.
תחזוקה לא בוצעה.
(Maintenance can only be done once every 12 hours.)
(ניתן לבצע תחזוקה רק מדי 12 שעות.)
Remove the "maintain" file or wait.
הסר את הקובץ "maintain" או המתן.
Expiring keep files and deleting pages marked for deletion
מוציא קבצי שמירה מתוקפם, ומוחק דפים שסומנו למחיקה
not deleted: 

deleted
נמחק
Moving part of the %s log file.
מזיז חלק מקובץ היומן %s.
Could not open %s log file
לא ניתן לפתוח את קובץ היומן %s
Error was
השגיאה היתה
Note: This error is normal if no changes have been made.
הערה: שגיאה זו היא רגילה אם לא בוצעו שינויים.
Moving %s log entries.
מזיז %s ערכי יומן.
Getting page index file for %s.

Set or Remove global edit lock
קבע או הסר נעילת עריכה גלובלית
Edit lock created.
נעילת עריכה נוצרה.
Edit lock removed.
נעילת עריכה הוסרה.
Set or Remove page edit lock
הגדר או הסר נעילת עריכה לדף.
Lock for %s created.
%s ננעל.
Lock for %s removed.
נעילה הוסרה מ-%s.
Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
יותר מדי חיבורים מ-%s.
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Learn more...

Complete Content
תוכן מלא
The main page is %s.
הדף הראשי הוא %s.
Archive:

Rebuild BackLink database

Internal Page: 

Pages that link to this page

Cannot highlight the language %s.

Recent Visitors
מבקרים מהזמן האחרון
some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

set %s

unset %s

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

List spammed pages

Despamming pages

Spammed pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Recover Draft

No text to save

Draft saved

Draft recovered

No draft available to recover

Save Draft

Draft Cleanup

%1 was last modified %2 and was kept

%1 was last modified %2 and was deleted

Unable to delete draft %s

Add Comment

ordinary changes

Matching page names:

Footnotes:

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:

Show!

Define

Full Link List
רשימת קישורים מלאה
Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

 (create locally)

image

download

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None

Type

Permalink to "%s"

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.

Use the back button to return the previous page and try again.

To save this page you must answer this question:

Referrers
מפנים
All Referrers
כל המפנים
Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.

Result pages: 

(%s results)

Tags:

Tags: %s.

No tags

Slideshow:%s

Index of all small pages

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Too many instances.  Only %s allowed.

Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.

Contents

Create a new page for today

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
חלופי
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
חיפוש
Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION

==> oddmuse-1.921.tar.gz: oddmuse-1.921/hebrew-utf8.pl <==
# UTF-8 encoded Hebrew language file for use with Oddmuse
#
# Copyright (c) 2003  Erez Zukerman, IDP, ezuk at idp dot co dot il
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: hebrew-utf8.pl,v 1.11 2009/06/07 19:30:37 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Include normal pages

Reading not allowed: user, ip, or network is blocked.

Login

Error

%s calls

Could not create %s
לא ניתן ליצור את %s
Invalid UserName %s: not saved.
שם משתמש שגוי: %s לא נשמר.
UserName must be 50 characters or less: not saved
שם המשתמש חייב להיות באורך 50 תווים או פחות: לא נשמר
This page contains an uploaded file:

Recursive include of %s!

Clear Cache

Main lock obtained.
נעילה ראשית הושגה.
Main lock released.
נעילה ראשית שוחררה.
Journal

More...

Comments on this page
הערות בדף זה
XML::RSS is not available on this system.

diff

history
היסטוריה
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

CGI Internal error: %s

Invalid action parameter %s
פרמטר שגוי לפעולה: %s
Page name is missing

Page name is too long: %s
שם הדף ארוך מדי: %s
Invalid Page %s (must not end with .db)
דף לא חוקי %s (אסור שיסתיים בסיומת .db)
Invalid Page %s (must not end with .lck)
דף לא חוקי %s (אסור שיסתיים בסיומת .lck)
Invalid Page %s
דף לא חוקי %s
Too many redirections

No redirection for old revisions

Invalid link pattern for #REDIRECT

Please go on to %s.
בבקשה המשך ל-%s.
Updates since %s
עדכונים מאז %s
Updates in the last %s days
עדכונים ב%s הימים האחרונים
Updates in the last %s day
עדכונים ביום האחרון
for %s only
עבור %s בלבד
List latest change per page only

List all changes

Skip rollbacks

Include rollbacks

List only major changes

Include minor changes

%s days
%s ימים
List later changes

RSS

RSS with pages

RSS with pages and diff

Filters

Title:

Title and Body:

Username:
שם משתמש:
Host:

Follow up to:

Language:

Go!
חפש!
(minor)
(קטן)
rollback

new

All changes for %s

from %s
מ %s
This page is too big to send over RSS.

History of %s
היסטוריה של %s
Compare
השוואה
Deleted

Mark this page for deletion

No other revisions available

current

Revision %s
עדכון %s
Contributors to %s

Missing target for rollback.

Target for rollback is too far back.

A username is required for ordinary users.

Rolling back changes

The two revisions are the same.

Editing not allowed for %s.
לא ניתן לערוך את %s.
Rollback to %s

%s rolled back

to %s

Index of all pages
תוכן כל הדפים:
Wiki Version
מציג את גירסת ה-Wiki.
Unlock Wiki
משחרר נעילה
Password
ססמה
Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[דף בית]
redirected from %s
הוכוון מחדש מ %s
%s: 

Click to search for references to this page

Cookie: 

Edit this page
ערוך את הטקסט של דף זה.
Preview:
תצוגה מקדימה:
Preview only, not yet saved
תצוגה מקדימה בלבד, הדף עדיין לא נשמר.
Warning
אזהרה
Database is stored in temporary directory %s
מסד הנתונים מאוחסן בספריה זמנית %s
%s seconds
%s שניות
Last edited
עריכה אחרונה
Edited
נערך
by %s

(diff)
(הבדלים)
Edit revision %s of this page
ערוך את גירסה %s של דף זה
e

This page is read-only
דף זה מיועד לקריאה בלבד
View other revisions
הצג גרסאות אחרות
View current revision
הצג את הגירסה העדכנית
View all changes

View contributors

Homepage URL:

s

Save
שמור
p

Preview
תצוגה מקדימה
Search:
חיפוש:
f

Replace:
החלפה:
Delete

Validate HTML
אמת HTML
Validate CSS
אמת CSS
Last edit

Difference between revision %1 and %2

revision %s
עדכון %s
current revision
גירסה נוכחית
Last major edit (%s)

later minor edits

No diff available.
לא ניתן להשיג הבדלים
Old revision:

Changed:
שונה:
Deleted:

Added:
התווסף:
to
אל
Revision %s not available
גירסה %s אינה זמינה.
showing current revision instead
מציג את הגירסה הנוכחית במקומה.
Showing revision %s
מציג את גירסה %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...
פעולה זו עשויה להימשך מספר שניות...
Forced unlock of %s lock.
שוחררה נעילה של %s.
No unlock required.
אין צורך לשחרר נעילה.
%s hours ago
לפני %s שעות.
1 hour ago
לפני שעה
%s minutes ago
לפני %s דקות
1 minute ago
לפני דקה
%s seconds ago
לפני %s שניות
1 second ago
לפני שניה
just now
ממש עכשיו
Edit Denied

Editing not allowed: user, ip, or network is blocked.
עריכה אסורה: משתמש, כתובת או רשת חסומים
Contact the wiki administrator for more information.
צור קשר עם מנהל המערכת למידע נוסף
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
לא ניתן לערוך: %s מיועד לקריאה בלבד.
Only administrators can upload files.

Editing revision %s of
עורך את גירסה %s של
Editing %s
עורך את %s
Editing old revision %s.
עורך גירסה ישנה %s.
Saving this page will replace the latest revision with this text.
שמירת דף זה תחליף את הגירסה החדשה ביותר בטקסט זה.
Summary:
תקציר:
This change is a minor edit.
השינוי שאני מבצע הוא קטן.
Cancel

Replace this file with text

Replace this text with a file

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
הססמה שלך נשמרת כ-cookie, אם cookies מופעלות. Cookies עלולות ללכת לאיבוד אם תתחבר ממחשב אחר או מתוכנה אחרת.
You are currently an administrator on this site.
אתה כרגע מנהל באתר זה.
You are currently an editor on this site.
אתה כרגע עורך באתר זה.
You are a normal user on this site.
אתה משתמש רגיל באתר זה.
Your password does not match any of the  administrator or editor passwords.
הססמה שלך לא מתאימה ללסמאות של המנהל או העורך.
Password:
ססמה:
This site does not use admin or editor passwords.
אתר זה לא משתמש בססמאות מנהל ועורך.
This operation is restricted to site editors only...
פעולה זו מוגבלת לעורכים בלבד...
This operation is restricted to administrators only...
פעולה זו מוגבלת למנהלים בלבד...
SampleUndefinedPage

Sample_Undefined_Page
דף_לא_מוגדר_לדוגמא
Rule "%1" matched "%2" on this page.

Reason: %s.

Reason unknown.

Filter:

(for %s)

%s pages found.

Replaced: %s
הוחלף: %s
Search for: %s
חיפוש של: %s
View changes for these pages

last updated
עדכון אחרון
by
על-ידי
Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
אנונימי
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
לא ניתן לגרום לנעילה להתמזג!
you

ancestor

other

Run Maintenance

Maintenance not done.
תחזוקה לא בוצעה.
(Maintenance can only be done once every 12 hours.)
(ניתן לבצע תחזוקה רק מדי 12 שעות.)
Remove the "maintain" file or wait.
הסר את הקובץ "maintain" או המתן.
Expiring keep files and deleting pages marked for deletion
מוציא קבצי שמירה מתוקפם, ומוחק דפים שסומנו למחיקה
not deleted: 

deleted
נמחק
Moving part of the %s log file.
מזיז חלק מקובץ היומן %s.
Could not open %s log file
לא ניתן לפתוח את קובץ היומן %s
Error was
השגיאה היתה
Note: This error is normal if no changes have been made.
הערה: שגיאה זו היא רגילה אם לא בוצעו שינויים.
Moving %s log entries.
מזיז %s ערכי יומן.
Set or Remove global edit lock
קבע או הסר נעילת עריכה גלובלית
Edit lock created.
נעילת עריכה נוצרה.
Edit lock removed.
נעילת עריכה הוסרה.
Set or Remove page edit lock
הגדר או הסר נעילת עריכה לדף.
Lock for %s created.
%s ננעל.
Lock for %s removed.
נעילה הוסרה מ-%s.
Displaying Wiki Version

Debugging Information

Inter links:

Too many connections by %s
יותר מדי חיבורים מ-%s.
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Learn more...

Complete Content
תוכן מלא
The main page is %s.
הדף הראשי הוא %s.
Archive:

Rebuild BackLink database

Internal Page: 

Pages that link to this page

The search parameter is missing.

Pages link to %s

Cannot highlight the language %s.

Recent Visitors
מבקרים מהזמן האחרון
some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

set %s

unset %s

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

List spammed pages

Despamming pages

Spammed pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Recover Draft

No text to save

Draft saved

Draft recovered

No draft available to recover

Save Draft

Draft Cleanup

%1 was last modified %2 and was kept

%1 was last modified %2 and was deleted

Unable to delete draft %s

Add Comment

ordinary changes

Matching page names:

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:

Show!

Define

Full Link List
רשימת קישורים מלאה
List of locked pages

Pages tagged with %s

Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Locked Pages

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

Invalid Mail %s: not saved.

unsubscribe

subscribe

Email: 

%s appears to be an invalid mail address

Your mail subscriptions

All mail subscriptions

Subscriptions

Show

Subscriptions for %s:

Unsubscribe

There are no subscriptions for %s.

Change email address

Mail addresses are linked to unsubscription links.

Subscribe to %s.

Subscribe

Subscribed %s to the following pages:

The remaining pages do not exist.

Unsubscribed %s from the following pages:

You linked more than %s times to the same domain. It would seem that only a spammer would do this. Your edit is refused.

%s is not a legal name for a namespace

Namespaces

Getting page index file for %s.

Near links:

Search sites on the %s as well

Fetching results from %s:

Near pages:

Include near pages

EditNearLinks

The same page on other sites:

 (create locally)

image

download

Backlinks

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

OpenID Login

Your identity is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

Your homepage is set to %s.

You have no homepage set.

Homepage:

Homepage is missing

OpenID error %s

Orphan List

Trail: 

None

Type

Permalink to "%s"

anchor first defined here: %s

the page %s also exists

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Click to search for references to this permanent anchor

Include permanent anchors

Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.

To save this page you must answer this question:

Please type the following two words:

Please answer this captcha:

Referrers
מפנים
All Referrers
כל המפנים
Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

New Pages for Indexed Search

List changes since %s

 ... 

Search term missing.

Result pages: 

(%s results)

Tags:

Tags: %s.

No tags

Page list for %s

Slideshow:%s

Index of all small pages

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Feed for this tag

Rebuild tag index

list tags

tag cloud

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Too many instances.  Only %s allowed.

Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.

Contents

Create a new page for today

Add Translation

Added translation: %1 (%2)

Translate %s

Thank you for writing a translation of %s.

Please indicate what language you will be using.

Language is missing

Suggested languages:

Please indicate a page name for the translation of %s.

More help may be available here: %s.

Translated page: 

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
חלופי
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
חיפוש
Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION
